
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.23.9.post1',
    'branch_nick': 'hotfix-source-mismatch',
    'revision_id': '54bd8b55ec57710311b4d499d436049cc83082c0',
    'revno': 10056
}
